@@ -19,9 +19,14 @@
 #ifndef COMMON_H
 #define COMMON_H
 
-#define _(String) String
+#include <locale.h>
+
+#include "gettext.h"
+
+#define _(String) gettext(String)
 
 typedef struct buffer buffer;
 typedef struct results results;
+typedef struct stream stream;
 
 #endif
