@@ -25,13 +25,18 @@
 #include <sqlext.h>
 
 void list_all_dsns();
-SQLHDBC db_connect(const char *, const char *, const char *);
-int db_reconnect(SQLHDBC *conn, const char *);
+SQLHDBC db_connect();
+void db_reconnect();
 SQLSMALLINT db_info(SQLHDBC, SQLUSMALLINT, char *, int);
+SQLINTEGER db_conn_attr(SQLHDBC, SQLINTEGER, char *, int);
 results *db_conn_details(SQLHDBC);
+int db_supports_catalogs(SQLHDBC);
 results *execute_query(SQLHDBC, const char *, int);
-void cancel_query();
+void db_cancel_query();
 results *get_tables(SQLHDBC, const char *, const char *, const char *);
 results *get_columns(SQLHDBC, const char *, const char *, const char *);
+results *db_list_schemas(SQLHDBC, const char *);
+results *db_list_tables(SQLHDBC, const char *);
+results *db_list_columns(SQLHDBC, const char *);
 
 #endif
