@@ -1,4 +1,4 @@
-#define HELP_INTRO \
+#define HELP_INTRO _(\
 "Help commands:\n" \
 "  help [<command>]\n" \
 "  copying\n" \
@@ -6,13 +6,15 @@
 "\n" \
 "Schema commands:\n" \
 "  catalogs\n" \
-"  schemas\n" \
-"  tables\n" \
-"  columns [<table>]\n" \
+"  schemas [<catalog>]\n" \
+"  tables [<catalog>]\n" \
+"  columns <table>\n" \
 "\n" \
 "Other commands:\n" \
 "  set [<variable>] [<value>]\n" \
-"  info"
+"  unset <variable>\n" \
+"  info" \
+		)
 
-#define HELP_NOTFOUND "Help topic doesn't exist"
+#define HELP_NOTFOUND _("Help topic doesn't exist")
 
