@@ -21,21 +21,47 @@
 
 #include <sys/time.h>
 #include <sql.h>
+#include <wchar.h>
+
+typedef struct resultset resultset;
+typedef struct row row;
 
 struct results {
-	SQLSMALLINT ncols;
-	SQLINTEGER nrows;
+	resultset *sets;
 	SQLINTEGER nwarnings;
-	char **cols;
-	char ***data;
-	char **warnings;
+	wchar_t **warnings;
 	struct timeval time_taken;
 };
 
+struct resultset {
+	SQLSMALLINT ncols;
+	SQLINTEGER nrows;
+	wchar_t **cols;
+	row *rows;
+	resultset *next;
+};
+
+struct row {
+	wchar_t **data;
+	row *next;
+};
+
 results *results_alloc();
-void results_set_cols(results *, int, ...);
+results *results_single_alloc();
+resultset *results_add_set();
 void results_set_warnings(results *, int, ...);
-void results_set_rows(results *, int);
+void results_set_cols(results *, int, ...);
+row *results_add_row(results *, ...);
 void results_free(results *);
 
+resultset *resultset_alloc();
+void resultset_set_cols(resultset *, int, ...);
+row *resultset_add_row(resultset *, ...);
+void resultset_free(resultset *);
+
+row *results_row_alloc(int);
+void results_row_free(row *, int);
+
+wchar_t *strdup2wcs(const char *);
+
 #endif
